@@ -11,6 +11,7 @@ class EscrowPaymentCondition(ConditionBase):
                 amounts,
                 receivers,
                 sender_address,
+                token_address,
                 lock_condition_id,
                 release_condition_id,
                 account):
@@ -22,6 +23,7 @@ class EscrowPaymentCondition(ConditionBase):
         :param amounts: Array of amount of tokens to distribute, int[]
         :param receivers: Array of ethereum address of the receivers, hex str[]
         :param sender_address: ethereum address of the sender, hex str
+        :param token_address: the token address to use. If empty  it will use 0x0 address that means ETH payment
         :param lock_condition_id: id of the condition, str
         :param release_condition_id: id of the condition, str
         :param account: Account instance
@@ -33,6 +35,7 @@ class EscrowPaymentCondition(ConditionBase):
             amounts,
             receivers,
             sender_address,
+            ConditionBase.validate_token_address(token_address),
             lock_condition_id,
             release_condition_id,
             transact={'from': account.address,
@@ -40,7 +43,7 @@ class EscrowPaymentCondition(ConditionBase):
                       'keyfile': account.key_file}
         )
 
-    def hash_values(self, did, amounts, receivers, sender_address, lock_condition_id,
+    def hash_values(self, did, amounts, receivers, sender_address, token_address, lock_condition_id,
                     release_condition_id):
         """
         Hash the values of the escrow reward condition.
@@ -49,6 +52,7 @@ class EscrowPaymentCondition(ConditionBase):
         :param amounts: Array of amount of tokens to distribute, int[]
         :param receivers: Array of ethereum address of the receivers, hex str[]
         :param sender_address: ethereum address of the sender, hex str
+        :param token_address: the token address to use. If empty  it will use 0x0 address that means ETH payment
         :param lock_condition_id: id of the condition, str
         :param release_condition_id: id of the condition, str
         :return: hex str
@@ -58,6 +62,7 @@ class EscrowPaymentCondition(ConditionBase):
             amounts,
             self.to_checksum_addresses(receivers),
             sender_address,
+            ConditionBase.validate_token_address(token_address),
             lock_condition_id,
             release_condition_id
         )
