@@ -30,8 +30,8 @@ class DIDRegistry(ContractBase):
 
     CONTRACT_NAME = 'DIDRegistry'
 
-    def registerMintableDID(self, did, checksum, url, cap, royalties, account, providers=None, activity_id=None,
-                            attributes=None):
+    def register_mintable_did(self, did, checksum, url, cap, royalties, account, providers=None, activity_id=None,
+                              attributes=None):
         """
         Register a mintable DID using the DIDRegistry smart contract.
 
@@ -115,6 +115,16 @@ class DIDRegistry(ContractBase):
         event = self.subscribe_to_event(self.DID_REGISTRY_EVENT_NAME, 15, _filters, wait=True)
         return event is not None
 
+    def are_royalties_valid(self, did, amounts, receivers):
+        """
+        Validates if asset royalties are valid
+        :param did:  Asset did, did
+        :param amounts: amounts to distribute
+        :param receivers: receivers of the amounts
+        :return: boolean
+        """
+        return self.contract.caller.areRoyaltiesValid(did, amounts, receivers)
+
     def get_block_number_updated(self, did):
         """Return the block number the last did was updated on the block chain."""
         return self.contract.caller.getBlockNumberUpdated(did)
@@ -352,7 +362,7 @@ class DIDRegistry(ContractBase):
         )
 
     def _register_mintable_did(self, did, checksum, providers, url, account, cap, royalties, activity_id=None,
-                      attributes=None):
+                               attributes=None):
         assert isinstance(providers, list), ''
         return self.send_transaction(
             'registerMintableDID',
@@ -465,6 +475,21 @@ class DIDRegistry(ContractBase):
     def is_provenance_signature_correct(self, agent_id, hash, signature):
         return self.contract.caller.provenanceSignatureIsCorrect(agent_id, hash, signature)
 
+    def get_did_register(self, did):
+        entry = self.contract.caller.getDIDRegister(did)
+        valid_providers = [a for a in entry[5] if a != '0x0000000000000000000000000000000000000000']
+        return {
+            'owner': entry[0],
+            'lastChecksum': entry[1],
+            'url': entry[2],
+            'lastUpdatedBy': entry[3],
+            'blockNumberUpdated': entry[4],
+            'providers': valid_providers,
+            'nftSupply': entry[6],
+            'mintCap': entry[7],
+            'royalties': entry[8]
+        }
+
     def get_provenance_entry(self, prov_id):
         provenance_entry = self.contract.caller.getProvenanceEntry(prov_id)
         return {'did': Web3.toHex(provenance_entry[0]),
@@ -584,6 +609,27 @@ class DIDRegistry(ContractBase):
         )
         return self.is_tx_successful(tx_hash)
 
+    def is_nft_approved_for_all(self, account, operator):
+        """
+        Return true if the operator address is ERC1155 approved
+
+        :param account: the account address to check, hex str
+        :param operator: ethereum operator address, hex str
+        :return: bool
+        """
+        return self.contract.caller.isApprovedForAll(account, operator)
+
+    def set_nft_proxy_approval(self, operator, approved, account):
+        tx_hash = self.send_transaction(
+            'setProxyApproval',
+            (operator, approved),
+            transact={'from': account.address,
+                      'passphrase': account.password,
+                      'keyfile': account.key_file}
+        )
+        return self.is_tx_successful(tx_hash)
+
+
     def _get_event_filter(self, event_name, did=None, owner=None, from_block=0, to_block='latest'):
         _filters = {}
         if event_name == DIDRegistry.PROVENANCE_WAS_DERIVED_FROM_EVENT_NAME:
